@@ -1,7 +1,37 @@
+# Copyright 2018 Venelin Mitov
+#
+# This file is part of POUMM.
+#
+# PCMBase is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# PCMBase is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with PCMBase.  If not, see <http://www.gnu.org/licenses/>.
+
 # Tree-processing functions
 
 NULL
 
+
+#' Check if the POUMM version correpsonds to a dev release
+#' @param numVersionComponents an integer, default 4.
+#' @importFrom utils packageDescription
+#' @description We define a dev release as having a sub-release, eg 0.9.15.5 is
+#' one whereas 0.9.16 is not. The number of components in the version can be
+#' changed through the argument numVersionComponents.
+#' @return a logical
+#' @export
+POUMMIsADevRelease <- function(numVersionComponents = 4L) {
+  !is.na( packageDescription("POUMM") ) &&
+    length(strsplit(packageDescription("POUMM")$Version, "\\.")[[1]]) >= numVersionComponents
+}
 printPOUMMLikelihoodMainLoop <- function(tree) {
   pruneInfo <- pruneTree(tree)
   M <- pruneInfo$M
@@ -217,7 +247,7 @@ simulatePOUMMLikelihoodMainLoop <- function(tree) {
   }
 }
 
-#' Node indices of the direct descendants of n in the phylogeny tree.
+#' Node indices of the direct descendants of n in the phylogeny.
 #' 
 #' @param tree an object of class phylo
 #' @param n an index of a node (root, internal or tip) in tree
